==> haskell-hoauth2-2.9.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.9.0
visibility:           public
id:                   hoauth2-2.9.0-3Tu7yTKBtGz2VikBvPHBVk
key:                  hoauth2-2.9.0-3Tu7yTKBtGz2VikBvPHBVk
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  c975f74da955cc0abd4f7010d6d89dc4
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.9.0-3Tu7yTKBtGz2VikBvPHBVk
depends:
    aeson-2.1.2.1-JT1gbb2shwLLy3Tf1UBGhr base-4.17.2.1
    base64-0.4.2.4-IJoc1K0SmWXDXjb06fasIC binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-HydAyLL1gdu3b98Fbi5D17
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    http-conduit-2.3.9.1-HbECnkVyaE45lgYK6bGwQQ
    http-types-0.12.4-CkuM9UJq4Wf7kbPBM7lhBh
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-6eb7U1BFarVKP2c0gTLzVO
    uri-bytestring-aeson-0.1.0.9-AARPQ6kuWQP5PHoMPuU6y3

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hoauth2-2.9.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hoauth2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.9.0
visibility:           public
id:                   hoauth2-2.9.0-DlzZzlK7ktZ6In1X0uAJgP
key:                  hoauth2-2.9.0-DlzZzlK7ktZ6In1X0uAJgP
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  3afbead7f227926e6acbf41045ba1389
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hoauth2-2.9.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.9.0-DlzZzlK7ktZ6In1X0uAJgP
depends:
    aeson-2.1.2.1-PtSa2Du7ZnC9cVeQoj7Qs base-4.17.2.1
    base64-0.4.2.4-31WPpcDxxba703UJmwu2og binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9aiao6Baet5LbFVZqeOgvR
    data-default-0.7.1.1-HuI8bY4bNR4F11jcRg6vOi exceptions-0.10.5
    http-conduit-2.3.9.1-94aJgyTH95jHzekYpqTURg
    http-types-0.12.4-LxNt591TVq8DuxWpmMdPSD
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    microlens-0.4.13.1-BCmTOusOWAwKF1xfvNhRYd text-2.0.2
    transformers-0.5.6.2 uri-bytestring-0.3.3.1-8N9IJw8XC229OEQlXqmMS4
    uri-bytestring-aeson-0.1.0.9-DKuRZa5D6FPA2k6TP3YBnq

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
